# Tutorials

## Quick Start
Get up and running with minimal setup. Learn how to install dependencies, prepare your data, and run your first example in just a few commands.

[Learn more](https://github.com/dataxight/protoplast-ml-example/blob/main/notebooks/simple_classifier_example.ipynb)


## Common Use Cases

### Train a Pertubation Model

Step through the process of training a model to predict cellular responses to genetic or chemical perturbations using your own single-cell datasets.

[Learn more](https://github.com/dataxight/protoplast-ml-example/blob/main/notebooks/perturbation_examples.ipynb)

### Use custom models

Integrate external machine learning models into the workflow. Learn how to plug in your own architectures or pretrained models for flexible experimentation.

[Learn more](https://github.com/dataxight/protoplast-ml-example/blob/main/notebooks/classification_examples.ipynb)

### Create a submission to the Virtual Cell Challenge

Learn how to package your trained model and datasets into the required format for the Virtual Cell Challenge. This section walks you through preparing submission files, validating them locally, and uploading your entry for official evaluation.

[Learn more](https://github.com/dataxight/protoplast-ml-example/blob/main/notebooks/protoplast_vcc.ipynb)

## More Tutorials

Please visit [protoplast-ml-example](https://github.com/dataxight/protoplast-ml-example) to get the latest examples of PROTOplast.